package A08.model;

import java.util.*;
import java.io.*;

public class Scheduler {

  static final int DAYS_IN_WEEK = 7;
  static final int MINUTES_IN_DAY = 1440;

  private boolean busyTimes[][];
  private int timeConstraint_startTime;
  private int timeConstraint_endTime; 
  //busyBlockList is a list of all the busy blocks
  //added so far
  private Vector<TimeUnit> busyBlockList;

  //constructor
  public Scheduler() {
	busyTimes = new boolean[DAYS_IN_WEEK][MINUTES_IN_DAY];
	for(int i=0; i<DAYS_IN_WEEK; i++) 
		for(int j=0; j<MINUTES_IN_DAY; j++)
			busyTimes[i][j] = false;

	timeConstraint_startTime = 0;
	timeConstraint_endTime = 1440;

        //create new busy block list
        busyBlockList = new Vector();
  }

  public void setTimeConstraint_StartTime(int sh, int sm) {
      int start = sh*60 + sm;
      timeConstraint_startTime = start;
  }

  public void setTimeConstraint_EndTime(int eh, int em) {
      int end = eh*60 + em;
      timeConstraint_endTime = end;
  }

  public void clearSchedule()
  {
       for(int i=0; i<DAYS_IN_WEEK; i++) 
		for(int j=0; j<MINUTES_IN_DAY; j++)
			busyTimes[i][j] = false;
  } 

  //getFreeTimes
  public String getFreeTimes() {

	String freeTimes = "<table border=1><tr>";
	double start = -1;
	double end = -1;
	boolean freeTimeFlag = false;
	TimeUnit tempTime = new TimeUnit(); 

	// find block
        for(int i=0; i<DAYS_IN_WEEK; i++) {
	    freeTimes += "<td valign=top>";
                for(int j=timeConstraint_startTime; j<=timeConstraint_endTime; j++) {
		    //start the free time block
                        if((busyTimes[i][j] == false) && (freeTimeFlag == false)) { 
				start = j;
				freeTimeFlag = true; 
			}

			//detect the end of the free time block
			if((busyTimes[i][j] == true) && (freeTimeFlag == true)) {
				end = j-1;
				freeTimeFlag = false; 
				
				double startHours = Math.floor(start/60);
				double startMinutes = start - (60*startHours);

				double endHours = Math.floor(end/60);
				double endMinutes = end - (60*endHours);

			 	tempTime.setTimeUnit(i,
						 (int)startHours,
						 (int)startMinutes,
						 (int)endHours,
						 (int)endMinutes);
				freeTimes += tempTime + "<br> ";
			}

			//special case where the free time block runs past minutes in the day
			if((freeTimeFlag == true) &&
			   (busyTimes[i][j] == false) &&
			   (j == (timeConstraint_endTime))) {

			    end = j;
			    freeTimeFlag = false; 
			    
			    double startHours = Math.floor(start/60);
			    double startMinutes = start - (60*startHours);
			    
			    double endHours = Math.floor(end/60);
			    double endMinutes = end - (60*endHours);

			    tempTime.setTimeUnit(i,
					     (int)startHours,
					     (int)startMinutes,
					     (int)endHours,
					     (int)endMinutes);
			    freeTimes += tempTime + "<br> ";
			}
		}
	freeTimes += "</td>";
	}
	freeTimes += "</tr></table>";
	return freeTimes;
  }

    public Vector addBusyBlock(TimeUnit busyBlock) {

	busyBlockList.add(busyBlock);
	

	int currentDay = busyBlock.getDay();
	int start = busyBlock.getStartHour()*60 + busyBlock.getStartMinutes();
	int end = busyBlock.getEndHour()*60 + busyBlock.getEndMinutes();

	for(int j=0; j<MINUTES_IN_DAY; j++) {
	    if( (j > start) && (j <= (end - 1)) ) {
		busyTimes[currentDay][j] = true;
	    }
	}
        return busyBlockList;
    }

    public Vector getBusyBlockList() {
	return busyBlockList;
    }


}
			 
